import { apiPath } from '@/redux/apiPath';
import { mockNetworkResponse } from '@/utils/mockNetworkResponse';
import { HttpStatusCode } from 'axios';
import { handleError } from '@/utils/error-report/errorReporting';
import { PUBLICATIONS_DEFAULT_SEARCH_FIRST_10_MOCK } from '../../../../../../models/mocks/publicationsResponseMock';
import { getBasePublications } from './getBasePublications';

const mockedAxiosClient = mockNetworkResponse();

jest.mock('./../../../../../../utils/error-report/errorReporting');

describe('getBasePublications - util', () => {
  const length = 10;

  it('should return valid data if provided', async () => {
    mockedAxiosClient
      .onGet(apiPath.getPublications({ params: { length } }))
      .reply(HttpStatusCode.Ok, PUBLICATIONS_DEFAULT_SEARCH_FIRST_10_MOCK);

    const result = await getBasePublications({ length });

    expect(result).toStrictEqual(PUBLICATIONS_DEFAULT_SEARCH_FIRST_10_MOCK.data);
  });

  it('should return empty array if data structure is invalid', async () => {
    mockedAxiosClient
      .onGet(apiPath.getPublications({ params: { length } }))
      .reply(HttpStatusCode.Ok, { randomObject: true });

    const result = await getBasePublications({ length });

    expect(result).toStrictEqual([]);
  });

  it('should return empty array and handle error if http error', async () => {
    mockedAxiosClient
      .onGet(apiPath.getPublications({ params: { length } }))
      .reply(HttpStatusCode.BadRequest);

    const result = await getBasePublications({ length });

    expect(result).toStrictEqual([]);
    expect(handleError).toHaveBeenCalled();
  });
});
