import { FIRST_ARRAY_ELEMENT } from '@/constants/common';
import { targetElementLeanResponseSchema } from '@/models/targetElementLeanResponseSchema';
import { apiPath } from '@/redux/apiPath';
import { BIO_ENTITY_FETCHING_ERROR_PREFIX } from '@/redux/bioEntity/bioEntity.constants';
import { axiosInstanceNewAPI } from '@/services/api/utils/axiosInstance';
import { BioEntityContent, BioEntityResponse } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { getError } from '@/utils/error-report/getError';
import { handleError } from '@/utils/error-report/errorReporting';
import { store } from '@/redux/store';

export const fetchElementData = async (
  searchQuery: string,
): Promise<BioEntityContent | undefined> => {
  try {
    const response = await axiosInstanceNewAPI.get<BioEntityResponse>(
      apiPath.getBioEntityContentsStringWithQuery({
        searchQuery,
        isPerfectMatch: true,
      }),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, targetElementLeanResponseSchema);

    if (isDataValid && response.data.content?.[FIRST_ARRAY_ELEMENT]) {
      return response.data.content[FIRST_ARRAY_ELEMENT];
    }
  } catch (error) {
    await handleError(
      getError({ error, prefix: BIO_ENTITY_FETCHING_ERROR_PREFIX }),
      store.getState(),
    );
  }

  return undefined;
};
