import type { AppListenerEffectAPI, AppStartListening } from '@/redux/store';
import { Action, createListenerMiddleware, isRejected } from '@reduxjs/toolkit';
import { handleError } from '@/utils/error-report/errorReporting';

export const errorListenerMiddleware = createListenerMiddleware();

const startListening = errorListenerMiddleware.startListening as AppStartListening;

export const errorMiddlewareListener = async (
  action: Action,
  { getState }: AppListenerEffectAPI,
): Promise<void> => {
  if (isRejected(action)) {
    await handleError(action.error, getState());
  }
};

startListening({
  matcher: isRejected,
  effect: errorMiddlewareListener,
});
